@@ -37,7 +37,7 @@ class CorreosHandler:
     def get_default_payload(self, instance):
         """
             This method generates by default all the necessary data with
-            an appropriate structure for Rayo courier.
+            an appropriate structure for Correos courier.
         """
         payload = {
             "nroDTE": 0,
@@ -110,6 +110,21 @@ class CorreosHandler:
             logger.error(error)
             raise ConnectorException(error.message, error.description, error.code) from error
 
+    def delete_shipping(self, shipping_number):
+        """
+            This method delete a shipping from Correos Chile.
+            Using the field 'numeroEnvio' from Correos response
+            as shipping number.
+        """
+        url = f'{self.base_url}/anulacion/{shipping_number}'
+        logger.debug(url)
+        try:
+            response = self.connector.delete(url, object_name="DELETE_SHIPPING")
+            return response
+        except ConnectorException as error:
+            logger.error(error)
+            raise ConnectorException(error.message, error.description, error.code) from error
+
     def get_tracking(self, identifier):
         raise NotImplementedError(
             'get_tracking is not a method implemented for CorreosHandler')
